function crosscorr = DiscreteCrossCorrelation(firstSignal,secondSignal,maxLag)

%Compute the discrete cross-correlation between two signals.
%
% USAGE: crosscorr = DiscreteCrossCorrelation(firstSignal,secondSignal,maxLag)
%
% PARAMETERS:
%   firstSignal ~ values of the first signal
%   secondSignal ~ values of the second signal
%   maxLag ~ the maximum value of the lag we want to compute
%
% RETURN VALUE:
%   crosscorr ~ values of the cross-correlation signal
% 
% DESCRIPTION:
%   This function computes the discrete cross-corrlation of two 1D signals.
%

% Copyright 2012, Xavier Alameda-Pineda
% INRIA Grenoble Rhone-Alpes
% E-mail: xavi.alameda@gmail.com
% 
% This is part of the gtde program.
% 
% gtde is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.

    %%% Check input
    if nargin < 3
        error('Usage: crosscorr = DiscreteCrossCorrelation(firstSignal,secondSignal,maxLag)');
    end
    
    %%% Initialize output
    crosscorr = zeros(1,2*maxLag+1);

    %%% Computation
    % Positive values of the delay
    for xcPos = 2:maxLag+1,
        crosscorr(maxLag+xcPos) = sum( firstSignal(1:end-xcPos+1) .* secondSignal(xcPos:end) );
        crosscorr(maxLag+2-xcPos) = sum( secondSignal(1:end-xcPos+1) .* firstSignal(xcPos:end) );
    end
    crosscorr(maxLag+1) = sum(firstSignal.*secondSignal);
    
return

