function PlotLocalizationErrorSpherical(foundTDEs,experimentOptions,~,localization)
% Copyright 2012, Xavier Alameda-Pineda
% INRIA Grenoble Rhône-Alpes
% E-mail: xavi.alameda@gmail.com
% 
% This is part of the gtde program.
% 
% gtde is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.

% Localization threshold
    locThreshold = 30;
    % Variables
    [nSignals,nPositions,nSNR,nT60,nMethod] = size(foundTDEs);
    % Microphones' origin
    origin = mean(experimentOptions.microphonePositions,1);
    % Method index: order display
%     methodIndex = [3 6 5 4 2 1 7];
    methodIndex = [1 7 5 2 6 4 3];
%     methodIndex = 1:6;
    if numel(methodIndex) ~= nMethod,
        error(['Method index not adapted to ' num2str(nMethod) ' methods.']);
    end
    % For each signal
    for sSignal = 1:nSignals,
        fprintf('  Signal %d:\n',sSignal);
        % Localization quality: for each signal and method, %outliers,
        % mean and std
        localizationQuality = zeros(nSNR,nT60,nMethod,3);
        for sSNR = 1:nSNR,
            % For each value of SNR and T60
            for sT60 = 1:nT60,
%                 fprintf('    T60 %1.2f:\n',experimentOptions.T60(sT60));
                % For each method
                for iMethod = 1:nMethod,
                    sMethod = methodIndex(iMethod);
%                     fprintf('Method %s:\n',experimentOptions.method{sMethod});
%                     % Prepare plot
%                     figure; %hold on;
                    % Localization error
                    globalFails = 0;
                    globalGuesses = 0;
                    globalLocError = [];
                    allErrors = [];
                    % Compute the difference with each instance
                    for sPos = 1:nPositions,
                        % Guesses & update global guesses
                        guesses = localization{sSignal,sPos,sSNR,sT60,sMethod};
                        % If isempty break
                        if isempty(guesses)
                            break;
                        end
                        globalGuesses = globalGuesses + size(guesses,1);
                        % Number of sub-signals
                        nPartialTrials = sum(~isnan(guesses(:,1)));
                        nNans = sum(isnan(guesses(:,1)));
                        globalFails = globalFails + nNans;
                        % Discard nans, and center with respect to origin
                        guesses(isnan(guesses(:,1)),:) = [];
                        guesses = guesses - repmat(origin,nPartialTrials,1);
                        % True position
                        truePosition = experimentOptions.sourcePositions(sPos,:) - origin;
                        % Repmat
                        truePosition = repmat(truePosition,nPartialTrials,1);
                        % Directional error, keep the closest ones
                        dErrors = 180*acos( sum(guesses.*truePosition,2)./ sqrt(sum(guesses.^2,2).*sum(truePosition.^2,2)) )/pi;
                        globalFails = globalFails  + sum(dErrors > locThreshold);                       
                        % Get all errors for plot
                        allErrors = cat(1,allErrors,dErrors);
                        % Crop out the outliers
                        dErrors = dErrors(dErrors <= locThreshold);
                        % Store the inliers
                        globalLocError = cat(1,globalLocError,dErrors);

%                         % If there is something to plot
%                         if ~isempty(dErrors)
%                             color = mean(dErrors)/180;
%                             msize = std(dErrors)+5;
%                             %%% 3D balls
%                             plot3(experimentOptions.sourcePositions(sPos,1),experimentOptions.sourcePositions(sPos,2),experimentOptions.sourcePositions(sPos,3),...
%                                 'ko','MarkerFaceColor',[ 1-color, 1-color, 1-color],'MarkerSize',msize);
%                         end
                        % Plot angular localization
%                         [th,ph,~] = cart2sph(guesses(:,1),guesses(:,2),guesses(:,3));
%                         plot(180*th/pi,180*ph/pi,'x','Color',getJetColor(sPos/nPositions));
%                         hold on
%                         [tth,tph,~] = cart2sph(truePosition(1,1),truePosition(1,2),truePosition(1,3));
%                         plot(180*tth/pi,180*tph/pi,'o','Color',getJetColor(sPos/nPositions));
%                         text(180*th/pi+3,180*ph/pi,num2str(sPos));
%                         text(180*tth/pi+3,180*tph/pi,num2str(sPos));
%                         axis([-200,200,-80,80]);
%                         hold off
%                         pause;
                    end
                    % Compute error statistics
                    localizationQuality(sSNR,sT60,sMethod,1,:) = 100*(globalGuesses-globalFails)/globalGuesses;
                    localizationQuality(sSNR,sT60,sMethod,2,:) = mean(globalLocError);
                    localizationQuality(sSNR,sT60,sMethod,3,:) = std(globalLocError);
                    
                    % Plot Histograms
%                     figure(sMethod);
%                     set(gcf,'Name',experimentOptions.method{sMethod},'units','normalized','outerposition',[0 0 1 1]);
                    figure(2);
%                     subplot(nMethod,nSNR*nT60,(iMethod-1)*nSNR*nT60+(nSNR-sSNR)*nT60+sT60), 
                    hist(allErrors,90);
                    h = findobj(gca,'Type','patch');
                    set(h,'FaceColor','k','EdgeColor','k');

                    set(gca,'XTick',[])%0:30:180);
%                     set(gca,'XTickLabel',{'0','30','60','90','120','150','180'});
                    set(gca,'YTick',[]);
                    xlabel('');
                    ylabel('');
                    axis off;
                    if strcmp(experimentOptions.method{sMethod},'canclini')
                        histFileName = strcat('/local_scratch/alamedap/Projects/ecmpr/papers/Alameda-gtde-journal/Histograms/',experimentOptions.method{sMethod},'-n_',num2str(experimentOptions.snrValues(sSNR)),'_',num2str(round(10*experimentOptions.T60(sT60))),'.png');
                        print(gcf,'-dpng',histFileName);
                    else
                        histFileName = strcat('/local_scratch/alamedap/Projects/ecmpr/papers/Alameda-gtde-journal/Histograms/',experimentOptions.method{sMethod},'_',num2str(experimentOptions.snrValues(sSNR)),'_',num2str(round(10*experimentOptions.T60(sT60))),'.png');
                        print(gcf,'-dpng',histFileName);
                    end
%                     title([experimentOptions.method{sMethod} ' SNR=' num2str(experimentOptions.snrValues(sSNR)) ' dB   T60=' num2str(experimentOptions.T60(sT60)) 's']);
                end
            end
        end
        
%         % For each SNR print a table
%         for sSNR=nSNR:-1:1,
% %             fprintf('SNR %f:\n',experimentOptions.snrValues(sSNR));
%             fprintf('\\multirow{%d}{*}{%d}',3*numel(experimentOptions.method),experimentOptions.snrValues(sSNR));
%             for iMethod = 1:nMethod,
%                 sMethod = methodIndex(iMethod);
%                 fprintf(' & \\multirow{3}{*}{\\textit{%s}} ',experimentOptions.method{sMethod});
% %                 fprintf(' & \\multirow{3}{*}{%1.1f}\t',experimentOptions.T60(sT60));
%                 % Print method name
% %                 for sMethod=1:nMethod, fprintf('& %s\t',experimentOptions.method{sMethod}(1:3)); end; fprintf('\n\t& &');
%                 % Print inliers
%                 for sT60 = 1:nT60, fprintf(' & %1.1f\\%% ',localizationQuality(sSNR,sT60,sMethod,1)); end; fprintf('\\\\\n\t\t & ');
%                 % Print mean
%                 for sT60 = 1:nT60, fprintf(' & %1.2f ',localizationQuality(sSNR,sT60,sMethod,2)); end; fprintf('\\\\\n\t\t & ');
%                 % Print std
%                 for sT60 = 1:nT60, fprintf(' & %1.2f ',localizationQuality(sSNR,sT60,sMethod,3)); end; fprintf('\\\\\n');
%                 if sMethod~=nMethod
%                     fprintf('\\cmidrule{2-%d}\n',numel(experimentOptions.T60)+2);
%                 end
%             end
%             if sSNR~=1
%                 fprintf('\\midrule\n');
%             end
%         end

%             fprintf('SNR %f:\n',experimentOptions.snrValues(sSNR));
%             fprintf('\\multirow{%d}{*}{%d}',3*numel(experimentOptions.method),experimentOptions.snrValues(sSNR));
        for iMethod = 1:nMethod,
            sMethod = methodIndex(iMethod);
            fprintf(' \\multirow{3}{*}{\\textit{%s}} ',experimentOptions.method{sMethod});
%                 fprintf(' & \\multirow{3}{*}{%1.1f}\t',experimentOptions.T60(sT60));
            % Print method name
%                 for sMethod=1:nMethod, fprintf('& %s\t',experimentOptions.method{sMethod}(1:3)); end; fprintf('\n\t& &');
            % Print inliers
            % For each SNR print a table
            for sSNR=nSNR:-1:1, for sT60 = 1:nT60, fprintf(' & %1.1f\\%% ',localizationQuality(sSNR,sT60,sMethod,1)); end; end; fprintf('\\\\\n\t\t ');
            % Print mean
            for sSNR=nSNR:-1:1, for sT60 = 1:nT60, fprintf(' & %1.2f ',localizationQuality(sSNR,sT60,sMethod,2)); end; end; fprintf('\\\\\n\t\t ');
            % Print std
            for sSNR=nSNR:-1:1, for sT60 = 1:nT60, fprintf(' & %1.2f ',localizationQuality(sSNR,sT60,sMethod,3)); end; end; fprintf('\\\\\n');

            if sMethod~=nMethod
                fprintf('\\cmidrule{2-%d}\n',numel(experimentOptions.T60)*numel(experimentOptions.snrValues)+1);
            end
        end
        if sSNR~=1
            fprintf('\\midrule\n');
        end

%         fprintf('\t Method \t'); for sSNR=1:nSNR, fprintf('%d\t',experimentOptions.snrValues(sSNR)); end; fprintf('\n');
%         fprintf('\t %%In \t'); for sSNR=1:nSNR, fprintf('%1.2f%%\t',localizationQuality(sSNR,sT60,sMethod,1)); end; fprintf('\n');
%         fprintf('\t Mean \t'); for sSNR=1:nSNR, fprintf('%1.2f\t',localizationQuality(sSNR,sT60,sMethod,2)); end; fprintf('\n');
%         fprintf('\t Std \t'); for sSNR=1:nSNR, fprintf('%1.2f\t',localizationQuality(sSNR,sT60,sMethod,3)); end; fprintf('\n');
    end
            
            
%             % SNR-plot
%             % For each localization variables       
%             %%% INLIERS
%             figure
%             hold on
%             for sT60 = 1:nT60,
%                 plot(experimentOptions.snrValues,100-squeeze(errorLocalization(:,sT60,1,1)),...
%                     strcat(lineSpec{sT60},tdeColor{sT60}),'LineWidth',3,...
%                     'MarkerFaceColor',tdeColor{sT60},'MarkerSize',15);
%                 grid on
%             end
%             axis([-16 11 0 100]);
%             set(gca,'FontSize',30);
%             xlabel('SNR (dB)','fontsize',30);
%             ylabel('Inliers (%)','fontsize',30);
%             %%% AZIMUTH
%             figure
%             hold on
%             for sT60 = 1:nT60,
%                 plot(experimentOptions.snrValues,squeeze(errorLocalization(:,sT60,2,1)),...
%                     strcat(lineSpec{sT60},tdeColor{sT60}),'LineWidth',3,...
%                     'MarkerFaceColor',tdeColor{sT60},'MarkerSize',15);
%     %             errorbar(experimentOptions.snrValues,...
%     %                 errorLocalization(:,sT60,2,1),...
%     %                 errorLocalization(:,sT60,3,1),...
%     %                 lineSpec{sT60});
%                 grid on
%             end
%             axis([-16 11 0 15]);
%             set(gca,'FontSize',30);
%             xlabel('SNR (dB)','fontsize',30);
%             ylabel('Azimuth MAE','fontsize',30);
%             %%% ELEVATION
%             figure
%             hold on
%             for sT60 = 1:nT60,
%                 plot(experimentOptions.snrValues,squeeze(errorLocalization(:,sT60,3,1)),...
%                     strcat(lineSpec{sT60},tdeColor{sT60}),'LineWidth',3,...
%                     'MarkerFaceColor',tdeColor{sT60},'MarkerSize',15);
%     %             errorbar(experimentOptions.snrValues,...
%     %                 errorLocalization(:,sT60,2,2),...
%     %                 errorLocalization(:,sT60,3,2),...
%     %                 lineSpec{sT60});
%                 grid on
%             end
%             axis([-16 11 0 15]);
%             set(gca,'FontSize',30);
%             xlabel('SNR (dB)','fontsize',30);
%             ylabel('Elevation MAE','fontsize',30);
end
