function PrepareDataTDEGUI(rootFolder,fileNames)
% Copyright 2012, Xavier Alameda-Pineda
% INRIA Grenoble Rhône-Alpes
% E-mail: xavi.alameda@gmail.com
% 
% This is part of the gtde program.
% 
% gtde is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.

    % Variables
    dataType = [];
    dataEnvironment = [];

    % For each file
    for fI = 1:numel(fileNames)
        % Load
        tmp = load(strcat(rootFolder,fileNames{fI}));
%         % Truth
%         if strcmp(tmp.experimentOptions.methodOptions.type,'truth'),
%             fprintf('%s\n',fileNames{fI});
%         end
        % Check data types
        [dataType, dataEnvironment] = checkData(dataType,dataEnvironment,tmp.experimentOptions);
        % In the real case, always prepareit, because we are recalibrating
        if strcmp(dataType,'real')
            preprocessResults(tmp,strcat(rootFolder,fileNames{fI}));
        end
        % If the data is not ready, prepare it!
        if ~isfield(tmp.experimentOptions,'resultsPreprocessed'),
            preprocessResults(tmp,strcat(rootFolder,fileNames{fI}));
        elseif ~tmp.experimentOptions.resultsPreprocessed,
            preprocessResults(tmp,strcat(rootFolder,fileNames{fI}));
        elseif strcmp(fileNames{fI},'096_.mat') %|| strcmp(fileNames{fI},'094_.mat') || strcmp(fileNames{fI},'095_.mat'),
            preprocessResults(tmp,strcat(rootFolder,fileNames{fI}));
        end
%         fprintf('%s, %1.2f\n',fileNames{fI},tmp.experimentOptions.microphonePositions(1));
    end
    

end

function preprocessResults(tmp,fileName)

    % Preproces the results
    errorTDEs = cell(size(tmp.foundTDEs));
    localization = cell(size(tmp.foundTDEs));
    % Sizes
    [nSignals,nPositions,nSNR,nT60] = size(errorTDEs);
    
%     tmpMics = load('newMics.mat');
%     tmp.experimentOptions.microphonePositions = tmpMics.newMics;
    
    % Loop on all of them
    for sPositions = 1:nPositions,
        trueTDEs = TDEGeometricDirect(tmp.experimentOptions.sourcePositions(1,:),...
                                      tmp.experimentOptions.microphonePositions);
        for sSignal = 1:nSignals,
            for sSNR = 1:nSNR,
                for sT60 = 1:nT60,
                    % # trials
                    nTrials = size(tmp.foundTDEs{sSignal,sPositions,sSNR,sT60},1);
                    % Error TDEs
                    errorTDEs{sSignal,sPositions,sSNR,sT60} = ...
                        tmp.foundTDEs{sSignal,sPositions,sSNR,sT60}-...
                        repmat(trueTDEs(1:3),nTrials,1);
                    % Localization
                    localization{sSignal,sPositions,sSNR,sT60} = nan(size(errorTDEs{sSignal,sPositions,sSNR,sT60},1),3);
                    for ii=1:nTrials,
                        % Recover position from TDEs
                        posCart = TDEGeometricInverse(tmp.experimentOptions.microphonePositions,...
                                                      tmp.foundTDEs{sSignal,sPositions,sSNR,sT60}(ii,:));
                        % If nto empty, save
                        if ~isempty(posCart)
                            localization{sSignal,sPositions,sSNR,sT60}(ii,:) = posCart;
                        end
                    end
                end
            end
        end
    end
    % Save we are done
    tmp.experimentOptions.resultsPreprocessed = true;
    
    % Save the new variables
    save(fileName,'-append','-struct','tmp','experimentOptions');
    save(fileName,'-append','errorTDEs','localization');

end


function [dataType, dataEnvironment] = checkData(dataType,dataEnvironment,experimentOptions)
    % Check data type
    if isempty(dataType)
        dataType = experimentOptions.dataOptions.type;
    else
        if ~strcmp(dataType, experimentOptions.dataOptions.type)
            error('Data types do not correspond. Please check selected files.');
        end
    end
    % In case of simulated data, check simulated environment
    switch dataType,
        case 'simulated',
            if isempty(dataEnvironment)
                [~,dataEnvironment,~] = fileparts(experimentOptions.ismOptions.folder);
            else
                [~,ismModel,~] = fileparts(experimentOptions.ismOptions.folder);
                if ~strcmp(dataEnvironment,ismModel)
                    error('Different simulated environments, check selected files.');
                end
            end
        case 'real',
            if isempty(dataEnvironment)
                [~,dataEnvironment,~] = fileparts(experimentOptions.dataOptions.wavRootFolder);
            else
                [~,realModel,~] = fileparts(experimentOptions.dataOptions.wavRootFolder);
                if ~strcmp(dataEnvironment, realModel)
                    error('Different real environments, check selected files.');
                end
            end
    end
end